@@ -19,7 +19,12 @@ def backtest(
     range_min: float,
     range_max: float,
     target: float,
-    base: int,
+    base: int = 0,
+    address: str = "",
+    startfrom: int = 0,
+    network: str = "",
+    dpd=None,
+    verbose=False,
 ):
     """
     Backtesting method for calculating returns on a specific strategy.
@@ -39,8 +44,14 @@ def backtest(
 
     """
 
-    dpd = graph(network, address, startfrom)
-    df_query = dpd.copy()
+    if dpd is None:
+        dpd = graph(network, address, startfrom)
+        df_query = dpd.copy()
+
+    # Decide if dpd is integer or time index
+    if isinstance(dpd.index, pd.DatetimeIndex):
+        # Convert to integer range
+        dpd.index = range(len(dpd.index))
 
     # Calculate decimals for pool tokens
     decimal0 = dpd.iloc[0]["pool.token0.decimals"]
@@ -91,11 +102,6 @@ def backtest(
     # first_date = dpd['periodStartUnix'].iloc[-1].strftime("%m/%d/%Y, %H:%M:%S")
     # first_close_price = dpd['close'].iloc[-1]
     # print(f"Closing price on {first_date}: {first_close_price}")
-    print("Amounts:", amount0, "/", amount1)
-    print(
-        "Amount ratios:", round(amount0_ratio, 2), "% /", round(amount1_ratio, 2), "%"
-    )
-
     # Use get_liquidity function from liquidity module
     myliquidity = get_liquidity(
         dpd["price0"].iloc[-1],
@@ -106,8 +112,16 @@ def backtest(
         decimal0,
         decimal1,
     )
-
-    print("My liquidity:", myliquidity)
+    if verbose:
+        print("Amounts:", amount0, "/", amount1)
+        print(
+            "Amount ratios:",
+            round(amount0_ratio, 2),
+            "% /",
+            round(amount1_ratio, 2),
+            "%",
+        )
+        print("My liquidity:", myliquidity)
 
     # Calculate active liquidity
 
@@ -216,7 +230,7 @@ def backtest(
     dpd.index = pd.to_datetime(dpd["periodStartUnix"], unit="s")
 
     # Get charting for more detailed metrics
-    a1, a2, a3 = chart1(dpd, base, myliquidity)
+    a1, a2, a3 = chart1(dpd, base, myliquidity, verbose)
 
     # Format data for plotting -- Chart 3 and DPD
     # Concat dataframes and drop duplicate columns
@@ -332,6 +346,11 @@ def get_token_amounts_and_IL(
     dpd["amount0"] = 0
     dpd["amount1"] = 0
 
+    # Decide if dpd is integer or time index
+    if isinstance(dpd.index, pd.DatetimeIndex):
+        # Convert to integer range
+        dpd.index = range(len(dpd.index))
+
     for i, row in dpd.iterrows():
         if dpd["high"].iloc[i] > range_min and dpd["low"].iloc[i] < range_max:
             dpd.iloc[i, dpd.columns.get_loc("ActiveLiq")] = (
@@ -408,7 +427,7 @@ def get_token_amounts_and_IL(
 def get_range_min_max_prices(
     dpd: pd.DataFrame, range_min: float, range_max: float, current_price: float
 ) -> pd.DataFrame:
-    df_artificial_dpd = dpd.copy()
+    df_artificial_dpd = dpd.copy(deep=True)
 
     # Get DataFrame to be able to split into 3 pieces
     modulo = 3
